#!/usr/bin/env python

# Copyright (C) 2007 ENPC - INRIA - EDF R&D
#   Author(s): Denis Quelo, Meryem Ahmed de Biasi
#
# This code is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License (file "license") for more details.

# This script is used to add anthropogenic and biogenic emissions.

from numpy import *

import os, sys, optparse, atmopy

usage = "%prog configuration_file\n\n" \
        + " configuration_file: configuration file," \
        + " defining all options and paths.\n" 
        
parser = optparse.OptionParser(usage = usage)

(options, args) = parser.parse_args()
       
if len(args) != 1:
	os.system(sys.argv[0] + " -h")
	sys.exit(2)
        
config_file = args[0]

config = atmopy.talos.ConfigStream(config_file)
input_anthropo = config.GetElement("Anthropogenic_directory", "[paths]")
input_bio = config.GetElement("Biogenic_directory", "[paths]")
output = config.GetElement("Output_directory", "[paths]")
Nx = config.GetInt("Nx", "[domain]")
Ny = config.GetInt("Ny", "[domain]")
Nz = config.GetInt("Nz", "[domain]")
Nta = config.GetInt("Nt", "[anthropogenic]")
Ntb = config.GetInt("Nt", "[biogenic]")

species_bio = [("NO", "NO"), ("Isoprene", "C5H8"), ("Terpenes", "APINEN")]

print "\nSumming anthropogenic and biogenic emissions.\n"
for s in species_bio:
	sb = s[0]
	sa = s[1]
	print "\nAnthropogenic species: " + sa + "."
	print "Biogenic species: " + sb + "."
	print "Computing total emissions for " + sa + "." 
	fa = input_anthropo + sa + ".bin"
	fb = input_bio + sb + ".bin"
	length = Nta * Nz * Ny * Nx
	x = fromfile(fa, 'f', length)
	x.shape = (Nta, Nz, Ny, Nx)
	x = x[:Ntb]
	length = Ntb * Nz * Ny * Nx
	y = fromfile(fb, 'f', length)
	y.shape = (Ntb, Nz, Ny, Nx)
	x += y
	x.tofile(output + sa + "-total.bin")

print "\n"
